@@ -17,14 +17,15 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: DesktopActions.java 1164 2006-10-17 19:48:42Z dmsmith $
+ * ID: $Id: DesktopActions.java 1394 2007-06-08 12:45:47Z dmsmith $
  */
 package org.crosswire.bibledesktop.desktop;
 
 import java.awt.Component;
 import java.awt.event.ActionEvent;
 import java.io.IOException;
-import java.net.URL;
+import java.lang.reflect.Method;
+import java.net.URI;
 import java.util.Iterator;
 
 import javax.swing.Action;
@@ -35,11 +36,14 @@ import javax.swing.ToolTipManager;
 import org.crosswire.bibledesktop.book.BibleViewPane;
 import org.crosswire.bibledesktop.book.install.SitesPane;
 import org.crosswire.bibledesktop.display.BookDataDisplay;
-import org.crosswire.bibledesktop.display.splitlist.SplitBookDataDisplay;
-import org.crosswire.bibledesktop.display.tab.TabbedBookDataDisplay;
+import org.crosswire.bibledesktop.display.basic.SplitBookDataDisplay;
+import org.crosswire.bibledesktop.display.basic.TabbedBookDataDisplay;
 import org.crosswire.common.config.swing.ConfigEditorFactory;
 import org.crosswire.common.swing.ActionFactory;
+import org.crosswire.common.swing.Actionable;
 import org.crosswire.common.swing.desktop.ViewVisitor;
+import org.crosswire.common.util.Logger;
+import org.crosswire.common.util.OSType;
 import org.crosswire.common.util.Reporter;
 import org.crosswire.jsword.book.Book;
 import org.crosswire.jsword.passage.Key;
@@ -57,9 +61,9 @@ import org.crosswire.jsword.util.Project;
  * @see gnu.gpl.License for license details.
  *      The copyright to this program is held by it's authors.
  * @author Joe Walker [joe at eireneh dot com]
- * @author DM Smith [dmsmith555 at gmail dot com]
+ * @author DM Smith [dmsmith555 at yahoo dot com]
  */
-public class DesktopActions
+public class DesktopActions implements Actionable
 {
     /**
      * Create the actions for the desktop
@@ -69,6 +73,8 @@ public class DesktopActions
     {
         this.desktop = desktop;
         actions = new ActionFactory(Desktop.class, this);
+
+        osxRegistered = macOSXRegistration();
     }
 
     /**
@@ -81,6 +87,14 @@ public class DesktopActions
         return actions.getAction(key);
     }
 
+    /* (non-Javadoc)
+     * @see org.crosswire.common.swing.Actionable#actionPerformed(java.lang.String)
+     */
+    public void actionPerformed(String action)
+    {
+        actions.actionPerformed(action);
+    }
+
     /**
      * @return the desktop to which these actions apply
      */
@@ -89,6 +103,15 @@ public class DesktopActions
         return desktop;
     }
 
+    /**
+     * Determines whether MacOSX has been registered.
+     * @return true when there is full MacOSX integration.
+     */
+    public boolean isOSXRegistered()
+    {
+        return osxRegistered;
+    }
+
     /**
      * @return the Bible installer dialog
      */
@@ -319,6 +342,15 @@ public class DesktopActions
         da.getBookDataDisplay().refresh();
     }
 
+    /**
+     * Show differences between Bible Book versions.
+     */
+    public void doCompareToggle(ActionEvent ev)
+    {
+        JCheckBoxMenuItem toggle = (JCheckBoxMenuItem) ev.getSource();
+        getDesktop().setCompareShowing(toggle.getState());
+    }
+
     public void doHeadings(ActionEvent ev)
     {
         JCheckBoxMenuItem toggle = (JCheckBoxMenuItem) ev.getSource();
@@ -371,7 +403,7 @@ public class DesktopActions
             return;
         }
 
-        Book book = da.getBook();
+        Book book = da.getFirstBook();
 
         ViewSourcePane viewer = new ViewSourcePane(book, key);
         viewer.showInFrame(getDesktop());
@@ -390,8 +422,8 @@ public class DesktopActions
      */
     public void doOptions()
     {
-        URL configUrl = Project.instance().getWritablePropertiesURL("desktop"); //$NON-NLS-1$
-        ConfigEditorFactory.showDialog(desktop.getConfig(), desktop, configUrl);
+        URI configUri = Project.instance().getWritablePropertiesURI("desktop"); //$NON-NLS-1$
+        ConfigEditorFactory.showDialog(desktop.getConfig(), desktop, configUri);
     }
 
     /**
@@ -452,6 +484,56 @@ public class DesktopActions
         desktop.showWebJournal(toggle.isSelected());
     }
 
+    /**
+     * Register the application with Apple EAWT, which provides support for the Application Menu, with
+     * About, Preferences (Options) and Quit (Exit).
+     * @return true on success
+     */
+    public boolean macOSXRegistration()
+    {
+        if (OSType.MAC.equals(OSType.getOSType()))
+        {
+            try
+            {
+                // Get a class object
+                Class osxAdapter = Class.forName("org.crosswire.common.aqua.OSXAdapter"); //$NON-NLS-1$
+
+                Class[] defRegisterArgs = { Actionable.class, String.class, String.class, String.class };
+                Method registerMethod = osxAdapter.getDeclaredMethod("registerMacOSXApplication", defRegisterArgs); //$NON-NLS-1$
+                if (registerMethod != null)
+                {
+                    Object[] args = { actions, DesktopActions.ABOUT, DesktopActions.OPTIONS, DesktopActions.EXIT };
+                    registerMethod.invoke(osxAdapter, args);
+                }
+
+                Class[] defEnablePrefArgs = { boolean.class };
+                Method prefsEnableMethod = osxAdapter.getDeclaredMethod("enablePrefs", defEnablePrefArgs); //$NON-NLS-1$
+                if (prefsEnableMethod != null)
+                {
+                    Object[] args = { Boolean.TRUE };
+                    prefsEnableMethod.invoke(osxAdapter, args);
+                }
+                return true;
+            }
+            catch (NoClassDefFoundError e)
+            {
+                // This is thrown when EAWT or MacOSXadapter is not present.
+                log.error("This version of Mac OS X does not support the Apple EAWT.  Application Menu handling has been disabled (" + e + ")");  //$NON-NLS-1$//$NON-NLS-2$
+            }
+            catch (ClassNotFoundException e)
+            {
+                // Should not happen
+                log.error("This version of Mac OS X does not support the Apple EAWT.  Application Menu handling has been disabled (" + e + ")");  //$NON-NLS-1$//$NON-NLS-2$
+            }
+            catch (Exception e)
+            {
+                // Everything else.
+                log.error("Exception while loading the OSXAdapter:", e); //$NON-NLS-1$
+            }
+        }
+        return false;
+    }
+
     /**
      *
      */
@@ -496,6 +578,7 @@ public class DesktopActions
     static final String COPY = "Copy"; //$NON-NLS-1$
     static final String BACK = "Back"; //$NON-NLS-1$
     static final String FORWARD = "Forward"; //$NON-NLS-1$
+    static final String COMPARE_TOGGLE = "CompareToggle"; //$NON-NLS-1$
     static final String TOOLTIP_TOGGLE = "ToolTipToggle"; //$NON-NLS-1$
     static final String STATUS_TOGGLE = "StatusToggle"; //$NON-NLS-1$
     static final String SIDEBAR_TOGGLE = "SidebarToggle"; //$NON-NLS-1$
@@ -517,6 +600,11 @@ public class DesktopActions
      */
     private ActionFactory actions;
 
+    /**
+     * Indicates whether there is MacOSX integration.
+     */
+    private boolean osxRegistered;
+
     /**
      * The About window
      */
@@ -526,4 +614,9 @@ public class DesktopActions
      * The Book installer window
      */
     private SitesPane sites;
+
+    /**
+     * The log stream
+     */
+    protected static final Logger log = Logger.getLogger(DesktopActions.class);
 }
