@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: KeySidebar.java 1261 2007-03-22 21:01:01Z dmsmith $
+ * ID: $Id: KeySidebar.java 1410 2007-06-15 21:59:12Z dmsmith $
  */
 package org.crosswire.bibledesktop.passage;
 
@@ -39,6 +39,7 @@ import javax.swing.event.ListSelectionListener;
 import org.crosswire.bibledesktop.book.DisplaySelectEvent;
 import org.crosswire.bibledesktop.book.DisplaySelectListener;
 import org.crosswire.common.swing.ActionFactory;
+import org.crosswire.common.swing.CWScrollPane;
 import org.crosswire.common.swing.GuiUtil;
 import org.crosswire.jsword.book.Book;
 import org.crosswire.jsword.passage.Key;
@@ -58,9 +59,9 @@ public class KeySidebar extends JPanel implements DisplaySelectListener, KeyChan
     /**
      * Initialize the SplitBookDataDisplay
      */
-    public KeySidebar(Book book)
+    public KeySidebar(Book[] books)
     {
-        this.book = book;
+        this.books = books == null ? null : (Book[]) books.clone();
         init();
         setActive();
     }
@@ -88,8 +89,7 @@ public class KeySidebar extends JPanel implements DisplaySelectListener, KeyChan
             }
         });
 
-        JScrollPane scroll = new JScrollPane();
-        scroll.getViewport().add(list);
+        JScrollPane scroll = new CWScrollPane(list);
 
         ActionFactory actions = new ActionFactory(KeySidebar.class, this);
 
@@ -264,7 +264,7 @@ public class KeySidebar extends JPanel implements DisplaySelectListener, KeyChan
 
         if (selected.length > 0)
         {
-            partial = book.createEmptyKeyList();
+            partial = books[0].createEmptyKeyList();
 
             for (int i = 0; i < selected.length; i++)
             {
@@ -309,7 +309,7 @@ public class KeySidebar extends JPanel implements DisplaySelectListener, KeyChan
      */
     public void bookChosen(DisplaySelectEvent ev)
     {
-        book = ev.getBook();
+        books = ev.getBookProvider().getBooks();
     }
 
     /* (non-Javadoc)
@@ -384,9 +384,9 @@ public class KeySidebar extends JPanel implements DisplaySelectListener, KeyChan
     private Key partial;
 
     /**
-     * The book who's keys we are looking at
+     * The books who's keys we are looking at
      */
-    private transient Book book;
+    private transient Book[] books;
 
     /**
      * The listener for KeyChangeEvents
