@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: Defaults.java 1264 2007-03-30 18:00:18Z dmsmith $
+ * ID: $Id: Defaults.java 1351 2007-05-25 16:34:16Z dmsmith $
  */
 package org.crosswire.jsword.book;
 
@@ -50,7 +50,7 @@ public final class Defaults
      */
     public static boolean isCurrentBible()
     {
-        return currentBible;
+        return trackBible;
     }
 
     /**
@@ -60,7 +60,7 @@ public final class Defaults
      */
     public static void setCurrentBible(boolean current)
     {
-        currentBible = current;
+        trackBible = current;
     }
 
     /**
@@ -73,10 +73,19 @@ public final class Defaults
         BookCategory type = book.getBookCategory();
         if (type.equals(BookCategory.BIBLE) && isCurrentBible())
         {
-            setBible(book);
+            currentBible = book;
         }
     }
 
+    public static Book getCurrentBible()
+    {
+        if (currentBible == null)
+        {
+            return bibleDeft.getDefault();
+        }
+        return currentBible;
+    }
+
     /* (non-Javadoc)
      * @see org.crosswire.jsword.book.DefaultBook#setDefault(org.crosswire.jsword.book.Book)
      */
@@ -440,35 +449,35 @@ public final class Defaults
     public static void refreshBooks()
     {
         // Create the array of Bibles
-        String[] bnames = getFullNameArray(BookFilters.getOnlyBibles());
+        String[] bnames = getNameArray(BookFilters.getOnlyBibles());
         ChoiceFactory.getDataMap().put(BIBLE_KEY, bnames);
 
         // Create the array of Commentaries
-        String[] cnames = getFullNameArray(BookFilters.getCommentaries());
+        String[] cnames = getNameArray(BookFilters.getCommentaries());
         ChoiceFactory.getDataMap().put(COMMENTARY_KEY, cnames);
 
         // Create the array of Dictionaries
-        String[] dnames = getFullNameArray(BookFilters.getDictionaries());
+        String[] dnames = getNameArray(BookFilters.getDictionaries());
         ChoiceFactory.getDataMap().put(DICTIONARY_KEY, dnames);
 
         // Create the array of DailyDevotionals
-        String[] rnames = getFullNameArray(BookFilters.getDailyDevotionals());
+        String[] rnames = getNameArray(BookFilters.getDailyDevotionals());
         ChoiceFactory.getDataMap().put(DAILY_DEVOTIONALS_KEY, rnames);
 
         // Create the array of Dictionaries
-        String[] greekDef = getFullNameArray(BookFilters.getGreekDefinitions());
+        String[] greekDef = getNameArray(BookFilters.getGreekDefinitions());
         ChoiceFactory.getDataMap().put(GREEKDEF_KEY, greekDef);
 
         // Create the array of Dictionaries
-        String[] hebrewDef = getFullNameArray(BookFilters.getHebrewDefinitions());
+        String[] hebrewDef = getNameArray(BookFilters.getHebrewDefinitions());
         ChoiceFactory.getDataMap().put(HEBREWDEF_KEY, hebrewDef);
 
         // Create the array of Dictionaries
-        String[] greekParse = getFullNameArray(BookFilters.getGreekParse());
+        String[] greekParse = getNameArray(BookFilters.getGreekParse());
         ChoiceFactory.getDataMap().put(GREEKPARSE_KEY, greekParse);
 
         // Create the array of Dictionaries
-        String[] hebrewParse = getFullNameArray(BookFilters.getHebrewParse());
+        String[] hebrewParse = getNameArray(BookFilters.getHebrewParse());
         ChoiceFactory.getDataMap().put(HEBREWPARSE_KEY, hebrewParse);
     }
 
@@ -507,7 +516,7 @@ public final class Defaults
     /**
      * Convert a filter into an array of names of Books that pass the filter.
      */
-    private static String[] getFullNameArray(BookFilter filter)
+    private static String[] getNameArray(BookFilter filter)
     {
         List names = new ArrayList();
 
@@ -515,7 +524,7 @@ public final class Defaults
         while (iter.hasNext())
         {
             Book book = (Book) iter.next();
-            names.add(book.getFullName());
+            names.add(book.getName());
         }
 
         return (String[]) names.toArray(new String[names.size()]);
@@ -566,7 +575,12 @@ public final class Defaults
     /**
      * Indicates whether the last book of each type is used next time.
      */
-    private static boolean currentBible = true;
+    private static boolean trackBible = true;
+
+    /**
+     * The current bible being tracked.
+     */
+    private static Book currentBible;
 
     /**
      * The default Bible
