@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: CustomHandler.java 1185 2006-11-13 13:32:18Z dmsmith $
+ * ID: $Id: CustomHandler.java 1263 2007-03-25 02:05:01Z dmsmith $
  */
 package org.crosswire.jsword.book.filter.thml;
 
@@ -262,10 +262,12 @@ public class CustomHandler extends DefaultHandler
             new UlTag(),
             new AliasTag("em", new ITag()), //$NON-NLS-1$
             new AliasTag("strong", new BTag()), //$NON-NLS-1$
-            new AliasTag("h1", new BTag()), //$NON-NLS-1$
-            new AliasTag("h2", new BTag()), //$NON-NLS-1$
-            new AliasTag("h3", new BTag()), //$NON-NLS-1$
-            new AliasTag("h4", new BTag()), //$NON-NLS-1$
+            new AliasTag("h1", new HTag(1)), //$NON-NLS-1$
+            new AliasTag("h2", new HTag(2)), //$NON-NLS-1$
+            new AliasTag("h3", new HTag(3)), //$NON-NLS-1$
+            new AliasTag("h4", new HTag(4)), //$NON-NLS-1$
+            new AliasTag("h5", new HTag(5)), //$NON-NLS-1$
+            new AliasTag("h6", new HTag(6)), //$NON-NLS-1$
             new AliasTag("dl", new UlTag()), //$NON-NLS-1$
             new AliasTag("dd", new LiTag()), //$NON-NLS-1$
             new AliasTag("dt", new LiTag()), //$NON-NLS-1$
