@@ -17,15 +17,14 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: AbstractSwordInstaller.java 1120 2006-08-26 17:35:11Z dmsmith $
+ * ID: $Id: AbstractSwordInstaller.java 1404 2007-06-14 11:17:36Z dmsmith $
  */
 package org.crosswire.jsword.book.install.sword;
 
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
-import java.net.MalformedURLException;
-import java.net.URL;
+import java.net.URI;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
@@ -33,14 +32,15 @@ import java.util.List;
 import java.util.Map;
 import java.util.zip.GZIPInputStream;
 
-import org.crosswire.common.progress.Job;
 import org.crosswire.common.progress.JobManager;
+import org.crosswire.common.progress.Progress;
 import org.crosswire.common.util.IOUtil;
 import org.crosswire.common.util.Logger;
 import org.crosswire.common.util.NetUtil;
 import org.crosswire.common.util.Reporter;
 import org.crosswire.jsword.book.Book;
 import org.crosswire.jsword.book.BookDriver;
+import org.crosswire.jsword.book.BookException;
 import org.crosswire.jsword.book.Books;
 import org.crosswire.jsword.book.basic.AbstractBookList;
 import org.crosswire.jsword.book.install.InstallException;
@@ -49,8 +49,8 @@ import org.crosswire.jsword.book.sword.ConfigEntry;
 import org.crosswire.jsword.book.sword.SwordBook;
 import org.crosswire.jsword.book.sword.SwordBookDriver;
 import org.crosswire.jsword.book.sword.SwordBookMetaData;
-import org.crosswire.jsword.book.sword.SwordConstants;
 import org.crosswire.jsword.book.sword.SwordBookPath;
+import org.crosswire.jsword.book.sword.SwordConstants;
 import org.crosswire.jsword.util.Project;
 
 import com.ice.tar.TarEntry;
@@ -73,16 +73,20 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
      * @param file The file to download
      * @throws InstallException
      */
-    protected abstract void download(Job job, String dir, String file, URL dest) throws InstallException;
+    protected abstract void download(Progress job, String dir, String file, URI dest) throws InstallException;
 
     /* (non-Javadoc)
-     * @see org.crosswire.jsword.book.install.Installer#getURL()
+     * @see org.crosswire.jsword.book.install.Installer#getInstallerDefinition()
      */
     public String getInstallerDefinition()
     {
         StringBuffer buf = new StringBuffer(host);
         buf.append(',');
-        buf.append(directory);
+        buf.append(packageDirectory);
+        buf.append(',');
+        buf.append(catalogDirectory);
+        buf.append(',');
+        buf.append(indexDirectory);
         buf.append(',');
         if (proxyHost != null)
         {
@@ -101,7 +105,7 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
      */
     public boolean isNewer(Book book)
     {
-        File dldir = SwordBookPath.getDownloadDir();
+        File dldir = SwordBookPath.getSwordDownloadDir();
 
         SwordBookMetaData sbmd = (SwordBookMetaData) book.getBookMetaData();
         File conf = new File(dldir, sbmd.getConfPath());
@@ -113,21 +117,10 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
             return false;
         }
 
-        URL configurl = null;
-        try
-        {
-            configurl = new URL(NetUtil.PROTOCOL_FILE, null, conf.getAbsolutePath());
+        URI configURI = NetUtil.getURI(conf);
 
-        }
-        catch (MalformedURLException ex)
-        {
-            log.error("Failed to create URL for file: " + conf, ex); //$NON-NLS-1$
-            assert false;
-            return false;
-        }
-
-        URL remote = toRemoteURL(book);
-        return NetUtil.isNewer(remote, configurl, proxyHost, proxyPort);
+        URI remote = toRemoteURI(book);
+        return NetUtil.isNewer(remote, configURI, proxyHost, proxyPort);
     }
 
     /* (non-Javadoc)
@@ -179,34 +172,45 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
             /* @Override */
             public void run()
             {
-                URL predicturl = Project.instance().getWritablePropertiesURL("sword-install"); //$NON-NLS-1$
-                Job job = JobManager.createJob(Msg.INSTALLING.toString(sbmd.getName()), predicturl, this, true);
+                URI predictURI = Project.instance().getWritablePropertiesURI("sword-install"); //$NON-NLS-1$
+                Progress job = JobManager.createJob(Msg.INSTALLING.toString(sbmd.getName()), predictURI, this, true);
 
                 yield();
 
                 try
                 {
-                    job.setProgress(Msg.JOB_INIT.toString());
+                    job.setSectionName(Msg.JOB_INIT.toString());
 
-                    URL temp = NetUtil.getTemporaryURL("swd", ZIP_SUFFIX); //$NON-NLS-1$
+                    URI temp = NetUtil.getTemporaryURI("swd", ZIP_SUFFIX); //$NON-NLS-1$
 
-                    download(job, directory + '/' + PACKAGE_DIR, sbmd.getInitials() + ZIP_SUFFIX, temp);
+                    download(job, packageDirectory, sbmd.getInitials() + ZIP_SUFFIX, temp);
 
                     // Once the unzipping is started, we need to continue
-                    job.setInterruptable(false);
-                    File dldir = SwordBookPath.getDownloadDir();
+                    job.setCancelable(false);
                     if (!job.isFinished())
                     {
+                        File dldir = SwordBookPath.getSwordDownloadDir();
                         IOUtil.unpackZip(NetUtil.getAsFile(temp), dldir);
-                        job.setProgress(Msg.JOB_CONFIG.toString());
-                        SwordBookDriver.registerNewBook(sbmd, dldir);
+                        job.setSectionName(Msg.JOB_CONFIG.toString());
+                        sbmd.setLibrary(NetUtil.getURI(dldir));
+                        SwordBookDriver.registerNewBook(sbmd);
                     }
 
                 }
-                catch (Exception ex)
+                catch (IOException e)
                 {
-                    Reporter.informUser(this, ex);
-                    job.ignoreTimings();
+                    Reporter.informUser(this, e);
+                    job.cancel();
+                }
+                catch (InstallException e)
+                {
+                    Reporter.informUser(this, e);
+                    job.cancel();
+                }
+                catch (BookException e)
+                {
+                    Reporter.informUser(this, e);
+                    job.cancel();
                 }
                 finally
                 {
@@ -225,17 +229,17 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
      */
     public void reloadBookList() throws InstallException
     {
-        Job job = JobManager.createJob(Msg.JOB_DOWNLOADING.toString(), Thread.currentThread(), false);
+        Progress job = JobManager.createJob(Msg.JOB_DOWNLOADING.toString(), Thread.currentThread(), false);
 
         try
         {
-            URL scratchfile = getCachedIndexFile();
-            download(job, directory + '/' + LIST_DIR, FILE_LIST_GZ, scratchfile);
+            URI scratchfile = getCachedIndexFile();
+            download(job, catalogDirectory, FILE_LIST_GZ, scratchfile);
             loaded = false;
         }
         catch (InstallException ex)
         {
-            job.ignoreTimings();
+            job.cancel();
             throw ex;
         }
         finally
@@ -245,20 +249,20 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
     }
 
     /* (non-Javadoc)
-     * @see org.crosswire.jsword.book.install.Installer#downloadSearchIndex(org.crosswire.jsword.book.BookMetaData, java.net.URL)
+     * @see org.crosswire.jsword.book.install.Installer#downloadSearchIndex(org.crosswire.jsword.book.BookMetaData, java.net.URI)
      */
-    public void downloadSearchIndex(Book book, URL localDest) throws InstallException
+    public void downloadSearchIndex(Book book, URI localDest) throws InstallException
     {
-        Job job = JobManager.createJob(Msg.JOB_DOWNLOADING.toString(), Thread.currentThread(), false);
+        Progress job = JobManager.createJob(Msg.JOB_DOWNLOADING.toString(), Thread.currentThread(), false);
 
         try
         {
-            download(job, directory + '/' + SEARCH_DIR, book.getInitials() + ZIP_SUFFIX, localDest);
+            download(job, packageDirectory + '/' + SEARCH_DIR, book.getInitials() + ZIP_SUFFIX, localDest);
         }
-        catch (Exception ex)
+        catch (InstallException ex)
         {
-            job.ignoreTimings();
-            throw new InstallException(Msg.UNKNOWN_ERROR, ex);
+            job.cancel();
+            throw ex;
         }
         finally
         {
@@ -277,7 +281,7 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
 
         entries.clear();
 
-        URL cache = getCachedIndexFile();
+        URI cache = getCachedIndexFile();
         if (!NetUtil.isFile(cache))
         {
             reloadBookList();
@@ -290,7 +294,7 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
         {
             ConfigEntry.resetStatistics();
 
-            in = cache.openStream();
+            in = NetUtil.getInputStream(cache);
             gin = new GZIPInputStream(in);
             tin = new TarInputStream(gin);
             while (true)
@@ -338,7 +342,7 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
                         Book book = new SwordBook(sbmd, null);
                         entries.put(book.getName(), book);
                     }
-                    catch (Exception ex)
+                    catch (IOException ex)
                     {
                         log.error("Failed to load config for entry: " + internal, ex); //$NON-NLS-1$
                     }
@@ -361,26 +365,58 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
         }
     }
 
+    /**
+     * @return the catologDirectory
+     */
+    public String getCatalogDirectory()
+    {
+        return catalogDirectory;
+    }
+
+    /**
+     * @param catologDirectory the catologDirectory to set
+     */
+    public void setCatalogDirectory(String catologDirectory)
+    {
+        this.catalogDirectory = catologDirectory;
+    }
+
     /**
      * @return Returns the directory.
      */
-    public String getDirectory()
+    public String getPackageDirectory()
     {
-        return directory;
+        return packageDirectory;
     }
 
     /**
      * @param newDirectory The directory to set.
      */
-    public void setDirectory(String newDirectory)
+    public void setPackageDirectory(String newDirectory)
     {
-        if (directory == null || !directory.equals(newDirectory))
+        if (packageDirectory == null || !packageDirectory.equals(newDirectory))
         {
-            directory = newDirectory;
+            packageDirectory = newDirectory;
             loaded = false;
         }
     }
 
+    /**
+     * @return the indexDirectory
+     */
+    public String getIndexDirectory()
+    {
+        return indexDirectory;
+    }
+
+    /**
+     * @param indexDirectory the indexDirectory to set
+     */
+    public void setIndexDirectory(String indexDirectory)
+    {
+        this.indexDirectory = indexDirectory;
+    }
+
     /**
      * @return Returns the host.
      */
@@ -449,12 +485,12 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
     /**
      * The URL for the cached index file for this installer
      */
-    protected URL getCachedIndexFile() throws InstallException
+    protected URI getCachedIndexFile() throws InstallException
     {
         try
         {
-            URL scratchdir = Project.instance().getTempScratchSpace(getTempFileExtension(host, directory), true);
-            return NetUtil.lengthenURL(scratchdir, FILE_LIST_GZ);
+            URI scratchdir = Project.instance().getTempScratchSpace(getTempFileExtension(host, catalogDirectory), true);
+            return NetUtil.lengthenURI(scratchdir, FILE_LIST_GZ);
         }
         catch (IOException ex)
         {
@@ -465,9 +501,9 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
     /**
      * What are we using as a temp filename?
      */
-    private static String getTempFileExtension(String host, String directory)
+    private static String getTempFileExtension(String host, String catalogDir)
     {
-        return DOWNLOAD_PREFIX + host + directory.replace('/', '_');
+        return DOWNLOAD_PREFIX + host + catalogDir.replace('/', '_');
     }
 
     /* (non-Javadoc)
@@ -487,7 +523,7 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
             return false;
         }
 
-        if (!equals(this.directory, that.directory))
+        if (!equals(this.packageDirectory, that.packageDirectory))
         {
             return false;
         }
@@ -505,7 +541,7 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
         int ret = host.compareTo(myClass.host);
         if (ret != 0)
         {
-            ret = directory.compareTo(myClass.directory);
+            ret = packageDirectory.compareTo(myClass.packageDirectory);
         }
         return ret;
     }
@@ -516,7 +552,7 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
     /* @Override */
     public int hashCode()
     {
-        return host.hashCode() + directory.hashCode();
+        return host.hashCode() + packageDirectory.hashCode();
     }
 
     /**
@@ -531,16 +567,6 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
         return string1.equals(string2);
     }
 
-    /**
-     * The relative path of the dir holding the zip files
-     */
-    protected static final String PACKAGE_DIR = "packages/rawzip"; //$NON-NLS-1$
-
-    /**
-     * The relative path of the dir holding the index file
-     */
-    private static final String LIST_DIR = "raw"; //$NON-NLS-1$
-
     /**
      * A map of the entries in this download area
      */
@@ -562,9 +588,19 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
     protected Integer proxyPort;
 
     /**
-     * The directory containing books on the <code>host</code>.
+     * The directory containing zipped books on the <code>host</code>.
      */
-    protected String directory = "/"; //$NON-NLS-1$
+    protected String packageDirectory = ""; //$NON-NLS-1$
+
+    /**
+     * The directory containing the catalog of all books on the <code>host</code>.
+     */
+    protected String catalogDirectory = ""; //$NON-NLS-1$
+
+    /**
+     * The directory containing the catalog of all books on the <code>host</code>.
+     */
+    protected String indexDirectory = ""; //$NON-NLS-1$
 
     /**
      * Do we need to reload the index file
@@ -595,4 +631,5 @@ public abstract class AbstractSwordInstaller extends AbstractBookList implements
      * When we cache a download index
      */
     protected static final String DOWNLOAD_PREFIX = "download-"; //$NON-NLS-1$
+
 }
