@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: ConfigEntryTable.java 1189 2006-11-18 13:22:36Z dmsmith $
+ * ID: $Id: ConfigEntryTable.java 1466 2007-07-02 02:48:09Z dmsmith $
  */
 package org.crosswire.jsword.book.sword;
 
@@ -36,11 +36,11 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 
+import org.crosswire.common.util.Languages;
 import org.crosswire.common.util.Logger;
 import org.crosswire.common.util.Reporter;
 import org.crosswire.jsword.book.BookCategory;
 import org.crosswire.jsword.book.OSISUtil;
-import org.crosswire.jsword.book.basic.AbstractBookMetaData;
 import org.jdom.Element;
 
 /**
@@ -203,7 +203,7 @@ public final class ConfigEntryTable
     /**
      * Unlocks a book with the given key.
      * The key is trimmed of any leading or trailing whitespace.
-     * 
+     *
      * @param unlockKey the key to try
      * @return true if the unlock key worked.
      */
@@ -231,7 +231,7 @@ public final class ConfigEntryTable
 
     /**
      * Gets the unlock key for the module.
-     * 
+     *
      * @return the unlock key, if any, null otherwise.
      */
     public String getUnlockKey()
@@ -273,7 +273,7 @@ public final class ConfigEntryTable
     /**
      * Determine whether this ConfigEntryTable has the ConfigEntry
      * and it matches the value.
-     * 
+     *
      * @param type The kind of ConfigEntry to look for
      * @param search the value to match against
      * @return true if there is a matching ConfigEntry matching the value
@@ -572,6 +572,10 @@ public final class ConfigEntryTable
     private void adjustDataPath()
     {
         String datapath = (String) getValue(ConfigEntryType.DATA_PATH);
+        if (datapath == null)
+        {
+            datapath = ""; //$NON-NLS-1$
+        }
         if (datapath.startsWith("./")) //$NON-NLS-1$
         {
             add(ConfigEntryType.DATA_PATH, datapath.substring(2));
@@ -605,7 +609,7 @@ public final class ConfigEntryTable
             langEntry = langFromEntry;
         }
 
-        String lang = AbstractBookMetaData.getLanguage(internal, langEntry);
+        String lang = getLanguage(internal, langEntry);
         add(ConfigEntryType.LANGUAGE, lang);
 
         // This returns Left to Right if
@@ -614,16 +618,16 @@ public final class ConfigEntryTable
 
         if (langFromEntry != null || langToEntry != null)
         {
-            String langFrom = AbstractBookMetaData.getLanguage(internal, langFromEntry);
+            String langFrom = getLanguage(internal, langFromEntry);
             add(ConfigEntryType.LANGUAGE_FROM, langFrom);
-            String langTo = AbstractBookMetaData.getLanguage(internal, langToEntry);
+            String langTo = getLanguage(internal, langToEntry);
             add(ConfigEntryType.LANGUAGE_TO, langTo);
             boolean fromLeftToRight = true;
             boolean toLeftToRight = true;
 
             if (langFromEntry == null)
             {
-                log.warn("Missing data for " + internal + ". Assuming " + ConfigEntryType.GLOSSARY_FROM.getName() + '=' + AbstractBookMetaData.DEFAULT_LANG_CODE);  //$NON-NLS-1$ //$NON-NLS-2$
+                log.warn("Missing data for " + internal + ". Assuming " + ConfigEntryType.GLOSSARY_FROM.getName() + '=' + Languages.DEFAULT_LANG_CODE);  //$NON-NLS-1$ //$NON-NLS-2$
             }
             else
             {
@@ -632,7 +636,7 @@ public final class ConfigEntryTable
 
             if (langToEntry == null)
             {
-                log.warn("Missing data for " + internal + ". Assuming " + ConfigEntryType.GLOSSARY_TO.getName() + '=' + AbstractBookMetaData.DEFAULT_LANG_CODE);  //$NON-NLS-1$ //$NON-NLS-2$
+                log.warn("Missing data for " + internal + ". Assuming " + ConfigEntryType.GLOSSARY_TO.getName() + '=' + Languages.DEFAULT_LANG_CODE);  //$NON-NLS-1$ //$NON-NLS-2$
             }
             else
             {
@@ -717,7 +721,7 @@ public final class ConfigEntryTable
         bookType = BookType.fromString(modTypeName);
         if (getBookType() == null)
         {
-            log.error("Book not supported: malformed conf file for " + internal + " no book type found"); //$NON-NLS-1$ //$NON-NLS-2$ 
+            log.error("Book not supported: malformed conf file for " + internal + " no book type found"); //$NON-NLS-1$ //$NON-NLS-2$
             supported = false;
             return;
         }
@@ -763,6 +767,15 @@ public final class ConfigEntryTable
 //        }
     }
 
+    private String getLanguage(String initials, String iso639Code)
+    {
+        if (!Languages.isValidLanguage(iso639Code))
+        {
+            log.warn("Unknown language " + iso639Code + " in book " + initials); //$NON-NLS-1$ //$NON-NLS-2$
+        }
+        return Languages.getLanguage(iso639Code);
+    }
+
     /**
      * Build an ordered map so that it displays in a consistent order.
      */
@@ -811,6 +824,7 @@ public final class ConfigEntryTable
             }
         }
     }
+
     private String report(String issue, String confEntryName, String line)
     {
         StringBuffer buf = new StringBuffer(100);
