@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: Verse.java 1188 2006-11-18 12:59:40Z dmsmith $
+ * ID: $Id: Verse.java 1466 2007-07-02 02:48:09Z dmsmith $
  */
 package org.crosswire.jsword.passage;
 
@@ -54,7 +54,7 @@ import org.crosswire.jsword.versification.BibleInfo;
  * Removing the default initialization of the ints took the time down by
  * about 0.25s also.
  * </p>
- * 
+ *
  * @see gnu.lgpl.License for license details.
  *      The copyright to this program is held by it's authors.
  * @author Joe Walker [joe at eireneh dot com]
@@ -143,10 +143,8 @@ public final class Verse implements Key, Serializable
         set(ordinal);
     }
 
-    /**
-     * Translate the Passage into a human readable string. This is
-     * simply an alias for getName();
-     * @return The string representation
+    /* (non-Javadoc)
+     * @see java.lang.Object#toString()
      */
     /* @Override */
     public String toString()
@@ -154,9 +152,8 @@ public final class Verse implements Key, Serializable
         return getName();
     }
 
-    /**
-     * Translate the Passage into a human readable string
-     * @return The string representation
+    /* (non-Javadoc)
+     * @see org.crosswire.jsword.passage.Key#getName()
      */
     public String getName()
     {
@@ -170,11 +167,11 @@ public final class Verse implements Key, Serializable
             // To cope with thing like Jude 2...
             if (BibleInfo.chaptersInBook(book) == 1)
             {
-                return BibleInfo.getBookName(book)
+                return BibleInfo.getPreferredBookName(book)
                     + Verse.VERSE_PREF_DELIM1
                     + verse;
             }
-            return BibleInfo.getBookName(book)
+            return BibleInfo.getPreferredBookName(book)
                 + Verse.VERSE_PREF_DELIM1
                 + chapter
                 + Verse.VERSE_PREF_DELIM2
@@ -187,10 +184,8 @@ public final class Verse implements Key, Serializable
         }
     }
 
-    /**
-     * Translate the Passage into a human readable string
-     * @param base The verse to use to cut down unnecessary output.
-     * @return The string representation
+    /* (non-Javadoc)
+     * @see org.crosswire.jsword.passage.Key#getName(org.crosswire.jsword.passage.Key)
      */
     public String getName(Key base)
     {
@@ -212,7 +207,7 @@ public final class Verse implements Key, Serializable
             {
                 if (verseBase.book != book)
                 {
-                    return BibleInfo.getBookName(book)
+                    return BibleInfo.getPreferredBookName(book)
                         + Verse.VERSE_PREF_DELIM1
                         + verse;
                 }
@@ -222,7 +217,7 @@ public final class Verse implements Key, Serializable
 
             if (verseBase.book != book)
             {
-                return BibleInfo.getBookName(book)
+                return BibleInfo.getPreferredBookName(book)
                     + Verse.VERSE_PREF_DELIM1
                     + chapter
                     + Verse.VERSE_PREF_DELIM2
@@ -245,10 +240,24 @@ public final class Verse implements Key, Serializable
         }
     }
 
-    /**
-     * The OSIS defined specification for this Verse.
-     * Uses short books names, with "." as a verse part separator.
-     * @return a String containing the OSIS description of the verses
+    /* (non-Javadoc)
+     * @see org.crosswire.jsword.passage.Key#getRootName()
+     */
+    public String getRootName()
+    {
+        try
+        {
+            return BibleInfo.getPreferredBookName(book);
+        }
+        catch (NoSuchKeyException ex)
+        {
+            assert false : ex;
+            return "!Error!"; //$NON-NLS-1$
+        }
+    }
+
+    /* (non-Javadoc)
+     * @see org.crosswire.jsword.passage.Key#getOsisRef()
      */
     public String getOsisRef()
     {
@@ -275,13 +284,8 @@ public final class Verse implements Key, Serializable
         return getOsisRef();
     }
 
-    /**
-     * Get a copy of ourselves. Points to note:
-     *   Call clone() not new() on member Objects, and on us.
-     *   Do not use Copy Constructors! - they do not inherit well.
-     *   Think about this needing to be synchronized
-     *   If this is not cloneable then writing cloneable children is harder
-     * @return A complete copy of ourselves
+    /* (non-Javadoc)
+     * @see java.lang.Object#clone()
      */
     /* @Override */
     public Object clone()
@@ -304,12 +308,8 @@ public final class Verse implements Key, Serializable
         return copy;
     }
 
-    /**
-     * Is this Object equal to us. Points to note:
-     *   If you override equals(), you must override hashCode() too.
-     *   If you are doing this it is a good idea to be immutable.
-     * @param obj The thing to test against
-     * @return True/False is we are or are not equal to obj
+    /* (non-Javadoc)
+     * @see java.lang.Object#equals(java.lang.Object)
      */
     /* @Override */
     public boolean equals(Object obj)
@@ -348,11 +348,8 @@ public final class Verse implements Key, Serializable
         return true;
     }
 
-    /**
-     * This returns the ordinal number of the verse
-     * so <code>new Verse("Rev 22:21").hashCode() = 31104</code>.
-     * <p><b>However should should not reply on this being true</b>
-     * @return The hashing number
+    /* (non-Javadoc)
+     * @see java.lang.Object#hashCode()
      */
     /* @Override */
     public int hashCode()
@@ -360,10 +357,8 @@ public final class Verse implements Key, Serializable
         return getOrdinal();
     }
 
-    /**
-     * Compare this to a given object
-     * @param obj The thing to compare against
-     * @return 1 means he is earlier than me, -1 means he is later ...
+    /* (non-Javadoc)
+     * @see java.lang.Comparable#compareTo(T)
      */
     public int compareTo(Object obj)
     {
@@ -878,13 +873,21 @@ public final class Verse implements Key, Serializable
     }
 
     /* (non-Javadoc)
-     * @see org.crosswire.jsword.passage.Key#size()
+     * @see org.crosswire.jsword.passage.Key#getChildCount()
      */
     public int getChildCount()
     {
         return 0;
     }
 
+    /* (non-Javadoc)
+     * @see org.crosswire.jsword.passage.Key#getCardinality()
+     */
+    public int getCardinality()
+    {
+        return 1;
+    }
+
     /* (non-Javadoc)
      * @see org.crosswire.jsword.passage.Key#isEmpty()
      */
@@ -985,7 +988,7 @@ public final class Verse implements Key, Serializable
     private static final int VERSE = 2;
 
     /**
-     * What characters should we use to separate parts of an OSIS verse reference 
+     * What characters should we use to separate parts of an OSIS verse reference
      */
     public static final String VERSE_OSIS_DELIM = "."; //$NON-NLS-1$
 
