@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: VerseRange.java 1221 2006-12-19 22:50:05Z dmsmith $
+ * ID: $Id: VerseRange.java 1466 2007-07-02 02:48:09Z dmsmith $
  */
 package org.crosswire.jsword.passage;
 
@@ -38,7 +38,7 @@ import org.crosswire.jsword.versification.BibleInfo;
  * necessary from a collections point of view. A VerseRange should always
  * be valid, although some versions may not return any text for verses
  * that they consider to be mis-translated in some way.
- * 
+ *
  * @see gnu.lgpl.License for license details.
  *      The copyright to this program is held by it's authors.
  * @author Joe Walker [joe at eireneh dot com]
@@ -164,18 +164,18 @@ public final class VerseRange implements Key, Serializable
                     // Just report the name of the book, we don't need to worry about the
                     // base since we start at the start of a book, and should have been
                     // recently normalized()
-                    return BibleInfo.getBookName(startBook)
+                    return BibleInfo.getPreferredBookName(startBook)
                          + VerseRange.RANGE_PREF_DELIM
-                         + BibleInfo.getBookName(endBook);
+                         + BibleInfo.getPreferredBookName(endBook);
                 }
 
                 // If this range is exactly a whole chapter
                 if (isWholeChapters())
                 {
                     // Just report book and chapter names
-                    return BibleInfo.getBookName(startBook)
+                    return BibleInfo.getPreferredBookName(startBook)
                          + Verse.VERSE_PREF_DELIM1 + startChapter
-                         + VerseRange.RANGE_PREF_DELIM + BibleInfo.getBookName(endBook)
+                         + VerseRange.RANGE_PREF_DELIM + BibleInfo.getPreferredBookName(endBook)
                          + Verse.VERSE_PREF_DELIM1 + endChapter;
                 }
 
@@ -188,7 +188,7 @@ public final class VerseRange implements Key, Serializable
                 // Just report the name of the book, we don't need to worry about the
                 // base since we start at the start of a book, and should have been
                 // recently normalized()
-                return BibleInfo.getBookName(startBook);
+                return BibleInfo.getPreferredBookName(startBook);
             }
 
             // If this is 2 separate chapters
@@ -198,7 +198,7 @@ public final class VerseRange implements Key, Serializable
                 if (isWholeChapters())
                 {
                     // Just report the name of the book and the chapters
-                    return BibleInfo.getBookName(startBook)
+                    return BibleInfo.getPreferredBookName(startBook)
                          + Verse.VERSE_PREF_DELIM1 + startChapter
                          + VerseRange.RANGE_PREF_DELIM + endChapter;
                 }
@@ -212,7 +212,7 @@ public final class VerseRange implements Key, Serializable
             if (isWholeChapter())
             {
                 // Just report the name of the book and the chapter
-                return BibleInfo.getBookName(startBook)
+                return BibleInfo.getPreferredBookName(startBook)
                      + Verse.VERSE_PREF_DELIM1 + startChapter;
             }
 
@@ -248,12 +248,48 @@ public final class VerseRange implements Key, Serializable
     {
         try
         {
-            // If this is in 2 separate books
             int startBook = start.getBook();
             int endBook = end.getBook();
+            int startChapter = start.getChapter();
+            int endChapter = end.getChapter();
+
+            // If this is in 2 separate books
             if (startBook != endBook)
             {
-                return start.getOsisRef() + VerseRange.RANGE_PREF_DELIM + end.getOsisRef();
+                StringBuffer buf = new StringBuffer();
+                if (start.isStartOfBook())
+                {
+                    buf.append(BibleInfo.getOSISName(startBook));
+                }
+                else if (start.isStartOfChapter())
+                {
+                    buf.append(BibleInfo.getOSISName(startBook));
+                    buf.append(Verse.VERSE_OSIS_DELIM);
+                    buf.append(startChapter);
+                }
+                else
+                {
+                    buf.append(start.getOsisRef());
+                }
+
+                buf.append(VerseRange.RANGE_PREF_DELIM);
+
+                if (end.isEndOfBook())
+                {
+                    buf.append(BibleInfo.getOSISName(endBook));
+                }
+                else if (end.isEndOfChapter())
+                {
+                    buf.append(BibleInfo.getOSISName(endBook));
+                    buf.append(Verse.VERSE_OSIS_DELIM);
+                    buf.append(endChapter);
+                }
+                else
+                {
+                    buf.append(end.getOsisRef());
+                }
+
+                return buf.toString();
             }
 
             // This range is exactly a whole book
@@ -265,25 +301,56 @@ public final class VerseRange implements Key, Serializable
                 return BibleInfo.getOSISName(startBook);
             }
 
-            // If this is 2 separate chapters
-            int startChapter = start.getChapter();
-            int endChapter = end.getChapter();
+            // If this is 2 separate chapters in the same book
             if (startChapter != endChapter)
             {
-                return start.getOsisRef() + VerseRange.RANGE_PREF_DELIM + end.getOsisRef();
+                StringBuffer buf = new StringBuffer();
+                if (start.isStartOfChapter())
+                {
+                    buf.append(BibleInfo.getOSISName(startBook));
+                    buf.append(Verse.VERSE_OSIS_DELIM);
+                    buf.append(startChapter);
+                }
+                else
+                {
+                    buf.append(start.getOsisRef());
+                }
+
+                buf.append(VerseRange.RANGE_PREF_DELIM);
+
+                if (end.isEndOfChapter())
+                {
+                    buf.append(BibleInfo.getOSISName(endBook));
+                    buf.append(Verse.VERSE_OSIS_DELIM);
+                    buf.append(endChapter);
+                }
+                else
+                {
+                    buf.append(end.getOsisRef());
+                }
+
+                return buf.toString();
             }
 
             // If this range is exactly a whole chapter
             if (isWholeChapter())
             {
                 // Just report the name of the book and the chapter
-                return BibleInfo.getOSISName(startBook) + Verse.VERSE_OSIS_DELIM + startChapter;
+                StringBuffer buf = new StringBuffer();
+                buf.append(BibleInfo.getOSISName(startBook));
+                buf.append(Verse.VERSE_OSIS_DELIM);
+                buf.append(startChapter);
+                return buf.toString();
             }
 
             // If this is 2 separate verses
             if (start.getVerse() != end.getVerse())
             {
-                return start.getOsisRef() + VerseRange.RANGE_PREF_DELIM + end.getOsisRef();
+                StringBuffer buf = new StringBuffer();
+                buf.append(start.getOsisRef());
+                buf.append(VerseRange.RANGE_PREF_DELIM);
+                buf.append(end.getOsisRef());
+                return buf.toString();
             }
 
             // The range is a single verse
@@ -334,7 +401,7 @@ public final class VerseRange implements Key, Serializable
         // Estimate the size of the buffer: book.dd.dd (where book is 3-5, 3 typical)
         StringBuffer buf = new StringBuffer((endOrdinal - startOrdinal + 1) * 10);
         buf.append(start.getOsisID());
-        for (int i = startOrdinal; i < endOrdinal; i++)
+        for (int i = startOrdinal + 1; i < endOrdinal; i++)
         {
             try
             {
